###########################################################
#
#  HTMLSLIDE v 1.4 12/18/2001
#  HTML slideshow creator
#  http://almen.wipcom.it/htmlslide/
#
#  Copyright (C) 2001 Menegon Alessandro <almen@wipcom.it>
#  This program is distributed under GPL license
#  Read COPYING for more information
#
#  Changes made June 2003 by Sudarshan S. Chawathe <chaw@cs.stanford.edu>
#  are also released under GNU GPL
#
###########################################################

## Subroutine che recupera il numero delle immagini
sub retrieve_photo_num()
{
  my $tot_num = 0;
  my $file = "$photo_position/.htmlslide/$index_file";
  open( FILE , "$file" );  # Apertura file
  while ( <FILE> )        # Finch non finisce il file
  {
    $tot_num ++;        # Conteggia il numero totale delle foto
  }
  close ( FILE );        # Chiusura file
  return $tot_num;        # Ritorna il numero delle foto
}

## Recupera il nome dell'immagine dalla posizione nel file index.txt
sub retrieve_content()
{
  my $photo_num = $_[0];
  my $image;
  my $i = 0;
  my $value = 0;
  my $name;
  my $comment;
  my $file = "$photo_position/.htmlslide/$index_file";
  open( FILE , "$file" );  # Apertura file
  while ( <FILE> )  # Finch non finisce il file
  {
    chop $_;
    ($name, $comment) = split(/${separator}/, $_);
    $i ++;
    if ( $i == $photo_num )
    {
      $value = $name;
    }
  }
  close ( FILE );
  return $value;
}

## Similar to retrieve_content, but returns the index-comment = icomment
sub retrieve_icomment()
{
  my $photo_num = $_[0];
  my $image;
  my $i = 0;
  my $value = 0;
  my $name;
  my $comment;
  my $icomment;
  my $file = "$photo_position/.htmlslide/$index_file";
  open( FILE , "$file" );  # Apertura file
  while ( <FILE> )  # Finch non finisce il file
  {
    chop $_;
    ($name, $comment, $icomment) = split(/${separator}/, $_);
    $i ++;
    if ( $i == $photo_num )
    {
      $value = $icomment;
      last;
    }
  }
  close ( FILE );
  if ($value eq "") {
      print "\nGenerating index-comment automagically for ${name}.\n";
      $value = &comment_to_icomment($comment);
  }
  return $value;
}

# Try to generate a short icomment from given comment string.
# All we do currently is truncate to $max_auto_icomment_len characters, adding 
# ... as a suffix.
sub comment_to_icomment()
{
    my $comment = $_[0];
    my $value = $comment;
    if (length($value) > $max_auto_icomment_len) {
	$value = substr($comment, 0, $max_auto_icomment_len)."...";
    }
    return $value;
}

# foo.jpg -> foo.txt, foo.jpeg -> foo.txt, foo.jPeG -> foo.txt, etc.
sub name_to_exifname()
{
    my $exifname = $_[0];
    $exifname =~ s/\.jpe?g$/.txt/i;
    return $exifname;
}

# NOTE: Assumes that the EXIF data files already exist in the appropriate dir.
# Depends on the specific format of jhead's results.
# see create_exif_file()
sub exif_date()
{
    my $exifname = $_[0];
    my $exiffile = "${photo_position}/.htmlslide/.exif/${exifname}";
    my $exifdate = `grep date < ${exiffile}`;
    $exifdate =~ s/file date[^0-9]*//i;
    return $exifdate;
}

# Create EXIF data files for given image file
sub create_exif_file()
{
    my $imagename = $_[0];
    my $exifname = $imagename;
    $exifname =~ s/\.jpe?g$/.txt/i;;
    my $exiffile = "$photo_position/.htmlslide/.exif/$exifname";

    # check if probable exif data file exists; if so, reuse.
    if (-e $exiffile) {
	print "\nReusing probable existing EXIF data: $exiffile\n";
    }
    else {
	my $command = "jhead $imagename > $exiffile";
	system($command);
	print("-"); #feedback
    }
}

## Creazione dei thumbnails
sub create_thumbnail()
{
	my $x;
	my $y;
	my $imagename = $_[0];
	my $x_s;
	my $y_s;
	my $command;
	my $thumbnail = "$photo_position/.htmlslide/.small/$imagename";

	# check if probable thumbnail file exists; if so, reuse.
	if (-e $thumbnail) {
	    print "\nReusing probable existing thumbnail: $thumbnail\n";
	}
	else {
	    # Recupera le dimensioni dell'immagine
	    ($x, $y) = imgsize("$photo_position/$imagename");
	    if($x >= $y)
	    {
		$x_s = $thumb_h;
		$y_s = ( $y / ( $x / $x_s ) );
	    }
	    else
	    {
		$y_s = $thumb_h;
		$x_s = ( $x / ( $y / $y_s ) );
	    }
	    
	    # Copia l'immagine nella cartella .small
	    copy("$photo_position/$imagename", "$photo_position/.htmlslide/.small/$imagename");
	    
	    # Ridimensiona l'immagine copiata
	    $command = "mogrify -geometry $x_s"."x".$y_s."! $photo_position_system/.htmlslide/.small/$imagename";
	    system($command);
	    print "."; # feedback	
	}
}

## Subroutine che fornisce in output il meta tag per lo slideshow
sub slide()
{
	my $content="";
	my $delay = $_[1];
	my $next_page = $_[0] + 1;
	my $photo_tot_num = $_[2];
	
	if($delay != 0 && ($next_page - 1) < $photo_tot_num)
	{
		$content = "<meta HTTP-EQUIV=\"refresh\" CONTENT=\"$delay; url='";
		if($next_page == 1)
		{
			$content .=".htmlslide/";
		}
		$content .= "$next_page.html'\">";
	}
	
	return $content;
}

## Subroutine che crea il file index.txt se non  presente o aggiunge le immagini .gif .png o .jpg
## che vengono trovate nella dir specificata ma che non sono nell'index.txt


return 1;
